import * as iam from 'aws-cdk-lib/aws-iam';
import { Construct } from 'constructs';
import { Middleware, MiddlewareBuilder } from '@project-lakechain/core/middleware';
import { ComputeType } from '@project-lakechain/core/compute-type';
import { PannsEmbeddingProcessorProps } from './definitions/opts';
/**
 * The PANNs embedding processor builder.
 */
declare class PannsEmbeddingProcessorBuilder extends MiddlewareBuilder {
    private providerProps;
    /**
     * The maximum amount of instances the
     * cluster can have. Keep this number to
     * a reasonable value to avoid over-provisioning
     * the cluster.
     * @param maxInstances the maximum amount of instances.
     * @default 5
     */
    withMaxInstances(maxInstances: number): this;
    /**
     * @returns a new instance of the `PannsEmbeddingProcessor`
     * service constructed with the given parameters.
     */
    build(): PannsEmbeddingProcessor;
}
/**
 * The Large-Scale Pre-trained Audio Neural Networks (PANNs)
 * embedding processor makes it possible to create vector
 * embeddings for audio documents.
 * @see https://github.com/qiuqiangkong/panns_inference
 */
export declare class PannsEmbeddingProcessor extends Middleware {
    private props;
    /**
     * The builder for the `PannsEmbeddingProcessor` service.
     */
    static Builder: typeof PannsEmbeddingProcessorBuilder;
    /**
     * Provider constructor.
     */
    constructor(scope: Construct, id: string, props: PannsEmbeddingProcessorProps);
    /**
     * Allows a grantee to read from the processed documents
     * generated by this middleware.
     */
    grantReadProcessedDocuments(grantee: iam.IGrantable): iam.Grant;
    /**
     * @returns an array of mime-types supported as input
     * type by this middleware.
     */
    supportedInputTypes(): string[];
    /**
     * @returns an array of mime-types supported as output
     * type by the data producer.
     */
    supportedOutputTypes(): string[];
    /**
     * @returns the supported compute types by a given
     * middleware.
     */
    supportedComputeTypes(): ComputeType[];
    /**
     * @returns the middleware conditional statement defining
     * in which conditions this middleware should be executed.
     * In this case, we want the middleware to only be invoked
     * when the document mime-type is supported, and the event
     * type is `document-created`.
     */
    conditional(): import("@project-lakechain/core/dsl/vocabulary/conditions").ConditionalStatement;
}
export {};
